@@ -1,4 +1,28 @@
 # coding:gbk
+from PyPoli import jr_jr
+from PyPoli import qq_JZ
+from PyPoli import weather_api
+from PyPoli import baid_dr
+from PyPoli import sj_pz
+from PyPoli import Hello
+from PyPoli import Time
+from PyPoli import calculation
+from PyPoli import open_url_exe
+from PyPoli import qq_tx_mz
+from PyPoli import chp
+from PyPoli import LT
+from PyPoli import kgmv
+from PyPoli import xh
+from PyPoli import lishi
+from PyPoli import twqh
+from PyPoli import tgrj
+from PyPoli import djt
+from PyPoli import rkl
+from PyPoli import sao_hua
+from PyPoli import sjyy
+from PyPoli import yq
+from PyPoli import fy
+from PyPoli import gen
 from RandomKey import key as k
 
 HELLO = ['hello']
